添加文档 | Lires
Description: Lires documentations

Skip to content

# 添加文档 ​

在添加条目后，可以向条目添加文档。目前支持的文档类型包括PDF, HTML 和 图像文件（图像文件会被转换为HTML）。

## 在主界面中添加 ​

欲添加文档，可以在主界面中点击数据卡片的`Actions`按钮，展开操作菜单， 点击`Upload document`即可选择并上传文档。

在条目包含文档后，数据卡片的`Upload document`按钮会变为`Free document`， 点击则会删除文档，以便重新上传。

## 在阅读器中添加 ​

当阅读器中没有文档的时候，会显示`No file, drag and drop to upload`的提示。 此时可以直接拖拽文档到阅读器中，或点击`upload`按钮上传。

此外，还可以点击右上角操作区的`replace`按钮选择并上传文档。 此时若存在原文档，无需提前删除，可以直接替换当前文档。